import { ApiInfo } from 'tencentcloud-sdk-nodejs/tencentcloud/services/apigateway/v20180808/apigateway_models';
import { Apigw } from '.';
import { ApiDeployerInputs, ApiDeployerOutputs, ApigwApiRemoverInputs, CreateOrUpdateApiInputs } from './interface';
/** API 网关组件 API 子模块 */
export declare class Api {
    /** API 网关组件 */
    apigw: Apigw;
    /**
     * 构造函数
     *
     * @param apigw API 网关组件（依赖注入）
     */
    constructor(apigw: Apigw);
    /**
     * 部署 API 网关 API列表
     *
     * @param inputs 部署 API 网关输入
     * @returns 部署 API 网关输出
     */
    apiDeployer(inputs: ApiDeployerInputs): Promise<ApiDeployerOutputs>;
    /**
     * 移除 API 网关 API
     *
     * @param inputs 移除 API 网关 API输入参数
     */
    apiRemover(inputs: ApigwApiRemoverInputs): Promise<void>;
    /**
     * 创建或更新 API 网关 API
     *
     * @param inputs 创建或更新 API 网关 API 输入
     * @returns 完成后的输出
     */
    createOrUpdateApi(inputs: CreateOrUpdateApiInputs): Promise<import("./interface").ApigwEndpoint>;
    /**
     * 通过服务 ID 和 API ID 获取 API 网关 API 信息
     *
     * @param inputs 输入
     * @param inputs.serviceId API 网关服务 ID
     * @param inputs.apiId API 网关 API ID
     * @returns API 详情
     */
    getApiById(inputs: {
        /** API 网关服务 ID */
        serviceId: string;
        /** API 网关 API ID */
        apiId: string;
    }): Promise<ApiInfo | undefined>;
    /**
     * 根据路径和方法获取 API 网关 API 信息
     *
     * @param inputs 输入参数
     * @param inputs.serviceId API 网关服务 ID
     * @param inputs.path API 网关 API 接受路径
     * @param inputs.method API 网关 API 接受方法
     * @returns API 网关 API 详情
     */
    getApiByPathAndMethod(inputs: {
        /** API 网关 serviceId */
        serviceId: string;
        /** API 路径 */
        path: string;
        /** API 网关 serviceId */
        method: string;
    }): Promise<ApiInfo | undefined>;
}
