import { Apigw } from '.';
import { ApigwBindCustomDomainInputs, ApigwBindCustomDomainOutputs, ApigwCustomDomain } from './interface';
/** 格式化的 API 网关自定义域名信息 */
interface FormattedApigwCustomDomain {
    /** 域名 */
    domain: string;
    /** 协议 */
    protocols: string;
    /** 证书 id */
    certificateId?: string;
    /** 是否是默认映射 */
    isDefaultMapping: boolean;
    /** 映射字典 */
    pathMappingSetDict: Record<string, string>;
    /** 网络类型 */
    netType: string;
}
/**
 * 判断是否是值类型
 *
 * @param obj 要判断的对象
 * @returns 是否是值类型
 */
export declare function isPrimitive(obj: any): boolean;
/**
 * 深度比较对象是否相等
 *
 * @param obj1 对象 1
 * @param obj2 对象 2
 * @returns 是否相等
 */
export declare function deepEqual(obj1: any, obj2: any): boolean;
/** API 网关组件自定义域名子模块 */
export declare class CustomDomain {
    /** API 网关组件 */
    apigw: Apigw;
    /**
     * 构造函数
     *
     * @param apigw API 网关组件（依赖注入）
     */
    constructor(apigw: Apigw);
    /**
     * 获取当前 API 自定义域名字典
     *
     * @param serviceId API ID
     * @returns 自定义域名字典
     */
    getCurrentCustomDomainsDict(serviceId: string): Promise<Record<string, FormattedApigwCustomDomain>>;
    /**
     * 解绑 API 网关所有由组件创建的自定义域名（通过查询 oldState）
     *
     * @param serviceId API 网关 ID
     * @param oldCustomDomains 状态中的自定义
     * @param currentDict 当前自定义域名字典
     * @param newDict 要绑定的自定义域名字典
     */
    unbindCustomDomain(serviceId: string, oldCustomDomains: ApigwCustomDomain[], currentDict?: Record<string, FormattedApigwCustomDomain>, newDict?: Record<string, FormattedApigwCustomDomain>): Promise<void>;
    /**
     * 为 API 网关服务绑定自定义域名
     *
     * @param root0 输入参数
     * @param root0.serviceId API 网关服务 ID
     * @param root0.subDomain API 网关子域名
     * @param root0.inputs API 网关绑定自定义域名输入
     * @returns 绑定成功后的输出
     */
    bindCustomDomain({ serviceId, subDomain, inputs, }: {
        /** API 网关服务 ID */
        serviceId: string;
        /** API 网关子域名 */
        subDomain: string;
        /** API 网关绑定自定义域名输入 */
        inputs: ApigwBindCustomDomainInputs;
    }): Promise<ApigwBindCustomDomainOutputs[]>;
}
export {};
