"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.marshalApiInput = exports.formatProtocolString = exports.marshalServiceConfig = void 0;
const common_1 = require("@tencent-serverless-framework/common");
/**
 * 格式化 API 网关
 *
 * @param endpoint API 网关 Endpoint
 * @param apiInputs API 网关部署输入
 */
function marshalServiceConfig(endpoint, apiInputs) {
    if (!endpoint.serviceConfig ||
        !endpoint.serviceConfig.url ||
        !endpoint.serviceConfig.path ||
        !endpoint.serviceConfig.method) {
        throw new common_1.ApiTypeError(`PARAMETER_APIGW`, '"endpoints.serviceConfig.url&path&method" is required');
    }
    apiInputs.serviceConfig = {
        url: endpoint.serviceConfig.url,
        path: endpoint.serviceConfig.path,
        method: endpoint.serviceConfig.method.toUpperCase(),
    };
}
exports.marshalServiceConfig = marshalServiceConfig;
/**
 * 获取协议字符串
 *
 * @param protocols 协议数组或字符串
 * @returns 协议字符串，如 'http&https'
 */
function formatProtocolString(protocols) {
    var _a;
    if (typeof protocols === 'string') {
        return protocols;
    }
    if (!protocols || protocols.length < 1) {
        return 'http';
    }
    const tempProtocol = protocols.join('&').toLowerCase();
    return (_a = (tempProtocol === 'https&http' ? 'http&https' : tempProtocol)) !== null && _a !== void 0 ? _a : 'http&https';
}
exports.formatProtocolString = formatProtocolString;
/**
 * 格式化 API 网关
 *
 * @param endpoint API 网关 Endpoint
 * @param apiInputs API 网关部署输入
 */
function marshalApiInput(endpoint, apiInputs) {
    if (endpoint.param) {
        apiInputs.requestParameters = endpoint.param;
    }
    const { serviceType } = apiInputs;
    // handle front-end API type of WEBSOCKET/HTTP
    if (endpoint.protocol === 'WEBSOCKET') {
        // handle WEBSOCKET API service type of WEBSOCKET/SCF
        if (serviceType === 'WEBSOCKET') {
            marshalServiceConfig(endpoint, apiInputs);
        }
        else {
            const funcNamespace = endpoint.function.functionNamespace || 'default';
            const funcQualifier = endpoint.function.functionQualifier
                ? endpoint.function.functionQualifier
                : '$LATEST';
            if (!endpoint.function.transportFunctionName) {
                throw new common_1.ApiTypeError(`PARAMETER_APIGW`, '"endpoints.function.transportFunctionName" is required');
            }
            apiInputs.serviceWebsocketTransportFunctionName = endpoint.function.transportFunctionName;
            apiInputs.serviceWebsocketTransportFunctionQualifier = funcQualifier;
            apiInputs.serviceWebsocketTransportFunctionNamespace = funcNamespace;
            apiInputs.serviceWebsocketRegisterFunctionName = endpoint.function.registerFunctionName;
            apiInputs.serviceWebsocketRegisterFunctionQualifier = funcQualifier;
            apiInputs.serviceWebsocketRegisterFunctionNamespace = funcNamespace;
            apiInputs.serviceWebsocketCleanupFunctionName = endpoint.function.cleanupFunctionName;
            apiInputs.serviceWebsocketCleanupFunctionQualifier = funcQualifier;
            apiInputs.serviceWebsocketCleanupFunctionNamespace = funcNamespace;
        }
    }
    else {
        // hande HTTP API service type of SCF/HTTP/MOCK
        switch (serviceType) {
            case 'SCF':
                endpoint.function = endpoint.function || {};
                if (!endpoint.function.functionName) {
                    throw new common_1.ApiTypeError(`PARAMETER_APIGW`, '"endpoints.function.functionName" is required');
                }
                apiInputs.serviceScfFunctionName = endpoint.function.functionName;
                apiInputs.serviceScfFunctionNamespace = endpoint.function.functionNamespace || 'default';
                apiInputs.serviceScfIsIntegratedResponse = endpoint.function.isIntegratedResponse
                    ? true
                    : false;
                apiInputs.serviceScfFunctionQualifier = endpoint.function.functionQualifier
                    ? endpoint.function.functionQualifier
                    : '$LATEST';
                break;
            case 'HTTP':
                marshalServiceConfig(endpoint, apiInputs);
                if (endpoint.serviceParameters && endpoint.serviceParameters.length > 0) {
                    apiInputs.serviceParameters = [];
                    for (let i = 0; i < endpoint.serviceParameters.length; i++) {
                        const inputParam = endpoint.serviceParameters[i];
                        const targetParam = {
                            name: inputParam.name,
                            position: inputParam.position,
                            relevantRequestParameterPosition: inputParam.relevantRequestParameterPosition,
                            relevantRequestParameterName: inputParam.relevantRequestParameterName,
                            defaultValue: inputParam.defaultValue,
                            relevantRequestParameterDesc: inputParam.relevantRequestParameterDesc,
                            relevantRequestParameterType: inputParam.relevantRequestParameterType,
                        };
                        apiInputs.serviceParameters.push(targetParam);
                    }
                }
                if (endpoint.serviceConfig.uniqVpcId) {
                    apiInputs.serviceConfig.uniqVpcId = endpoint.serviceConfig.uniqVpcId;
                    apiInputs.serviceConfig.product = 'clb';
                }
                break;
            case 'MOCK':
                if (!endpoint.serviceMockReturnMessage) {
                    throw new common_1.ApiTypeError(`PARAMETER_APIGW`, '"endpoints.serviceMockReturnMessage" is required');
                }
                apiInputs.serviceMockReturnMessage = endpoint.serviceMockReturnMessage;
        }
    }
}
exports.marshalApiInput = marshalApiInput;
