import { UsagePlanBindSecret } from 'tencentcloud-sdk-nodejs/tencentcloud/services/apigateway/v20180808/apigateway_models';
import { Apigw } from '.';
import { ApigwBindUsagePlanInputs, ApigwRemoveOrUnbindUsagePlanInputs, ApigwSetupUsagePlanInputs, ApigwSetupUsagePlanSecretInputs, ApigwUsagePlan } from './interface';
/**
 * 去除数组的重复值
 *
 * @param arr 数组
 * @returns 去除重复值后的数组
 */
export declare function uniqueArray<T>(arr: T[]): T[];
/** API 网关组件用量计划域名子模块 */
export declare class UsagePlan {
    /** API 网关组件 */
    apigw: Apigw;
    /**
     * 构造函数
     *
     * @param apigw API 网关组件（依赖注入）
     */
    constructor(apigw: Apigw);
    /**
     * 设置一对 API 密钥
     *
     * @param inputs 输入
     * @returns 密钥 id 列表
     */
    setupUsagePlanSecret(inputs: ApigwSetupUsagePlanSecretInputs): Promise<{
        created: boolean;
        secretIds: string[] | undefined;
    }>;
    /**
     * 获取 secrets 列表
     *
     * @param usagePlanId 用户计划 id
     * @param secrets 使用计划绑定密钥数组
     * @param options 获取时的选项
     * @param options.limit 至多获取多少项
     * @param options.offset 跳过多少项开始获取
     * @returns 使用计划 secrets 列表
     */
    getAllBoundSecrets(usagePlanId: string, secrets: UsagePlanBindSecret[] | undefined, options: {
        /** 至多获取多少项 */
        limit: number;
        /** 跳过多少项开始获取 */
        offset?: number;
    }): Promise<UsagePlanBindSecret[]>;
    /**
     * 找到所有未绑定的使用计划 secretIds
     *
     * @param root0 输入参数
     * @param root0.usagePlanId 使用计划 ID
     * @param root0.secretIds 使用计划密钥 ID 列表
     * @returns 找到的不存在的使用计划 id 列表
     */
    getUnboundSecretIds({ usagePlanId, secretIds, }: {
        /** 使用计划 ID */
        usagePlanId: string;
        /** 使用计划密钥 ID 列表 */
        secretIds: string[];
    }): Promise<string[]>;
    /**
     * 设置 API 网关的使用计划
     *
     * @param inputs API 网关的使用计划输入参数
     * @returns 使用计划的 id
     **/
    setupUsagePlan(inputs: ApigwSetupUsagePlanInputs): Promise<{
        created: boolean;
        usagePlanId: string;
    }>;
    /**
     * API 网关绑定用量计划
     *
     * @param inputs 输入
     * @returns 输出，绑定后的用量计划
     */
    bindUsagePlan(inputs: ApigwBindUsagePlanInputs): Promise<ApigwUsagePlan>;
    /**
     * 移除 API 网关的使用计划
     *
     * @param inputs 移除 API 网关的使用计划输入参数
     */
    removeOrUnbindUsagePlan(inputs: ApigwRemoveOrUnbindUsagePlanInputs): Promise<void>;
}
